@@ -4,7 +4,7 @@ import logging
 import multiprocessing as mp
 import os
 import shlex
-import subprocess
+import subprocess  # nosec B404
 from contextlib import AbstractContextManager, ExitStack
 from dataclasses import asdict, dataclass
 from typing import Any, Dict, List, Optional, Union
@@ -12,6 +12,7 @@ from typing import Any, Dict, List, Optional, Union
 from funcy import cached_property
 from shortuuid import uuid
 
+from ..contrib.kombu_filesystem import LOCK_EX, LOCK_SH, lock, unlock
 from ..utils import makedirs
 from .exceptions import TimeoutExpired
 
@@ -36,8 +37,12 @@ class ProcessInfo:
     @classmethod
     def load(cls, filename: str) -> "ProcessInfo":
         """Construct the process information from a file."""
-        with open(filename, "r", encoding="utf-8") as fobj:
-            return cls.from_dict(json.load(fobj))
+        with open(filename, encoding="utf-8") as fobj:
+            lock(fobj, LOCK_SH)
+            try:
+                return cls.from_dict(json.load(fobj))
+            finally:
+                unlock(fobj)
 
     def asdict(self) -> Dict[str, Any]:
         """Return this info as a dictionary."""
@@ -45,10 +50,12 @@ class ProcessInfo:
 
     def dump(self, filename: str) -> None:
         """Dump the process information into a file."""
-        temp_info_file = f"{filename}.{uuid()}"
-        with open(temp_info_file, "w", encoding="utf-8") as fobj:
-            json.dump(self.asdict(), fobj)
-        os.replace(temp_info_file, filename)
+        with open(filename, "w", encoding="utf-8") as fobj:
+            lock(fobj, LOCK_EX)
+            try:
+                json.dump(self.asdict(), fobj)
+            finally:
+                unlock(fobj)
 
 
 class ManagedProcess(AbstractContextManager):
@@ -160,7 +167,7 @@ class ManagedProcess(AbstractContextManager):
         stdout = self._fd_stack.enter_context(open(self.stdout_path, "ab"))
         try:
             # pylint: disable=consider-using-with
-            self._proc = subprocess.Popen(
+            self._proc = subprocess.Popen(  # nosec B603
                 self.args,
                 stdin=subprocess.DEVNULL,
                 stdout=stdout,
